<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.history.inc,v 1.1 2008/09/02 12:28:41 seeschloss Exp $

function tribune_history_page() {
  return drupal_get_form('tribune_history_form');
}

function tribune_history_form() {
  $form = array();

  $form['by-date'] = array(
    '#type' => 'fieldset',
    '#title' => t('Messages by date'),
    '#description' => t('See all the messages posted at a specific date.'),
  );
  $form['by-date']['by-date-date'] = array(
    '#type' => 'date',
  );
  $form['by-date']['by-date-submit'] = array(
    '#type' => 'submit',
    '#value' => t('By date'),
    '#submit' => array('tribune_history_by_date_handler'),
  );

  $form['by-user'] = array(
    '#type' => 'fieldset',
    '#title' => t('Messages by user'),
    '#description' => t('See all the messages posted by an user.'),
  );
  $form['by-user']['by-user-user'] = array(
    '#type' => 'textfield',
    '#autocomplete_path' => 'user/autocomplete',
  );
  $form['by-user']['by-user-submit-registered'] = array(
    '#prefix' => '<div class="container-inline">',
    '#type' => 'submit',
    '#value' => t('Registered user'),
    '#submit' => array('tribune_history_by_user_registered_handler'),
  );
  $form['by-user']['by-user-submit-anonymous'] = array(
    '#type' => 'submit',
    '#value' => t('Anonymous user'),
    '#suffix' => '</div>',
    '#submit' => array('tribune_history_by_user_anonymous_handler'),
  );

  $form['by-string'] = array(
    '#type' => 'fieldset',
    '#title' => t('Search messages'),
    '#description' => t('Search messages containing a string.'),
  );
  $form['by-string']['by-string-string'] = array(
    '#type' => 'textfield',
  );
  $form['by-string']['by-string-submit'] = array(
    '#type' => 'submit',
    '#value' => t('Search'),
    '#submit' => array('tribune_history_by_string_handler'),
  );

  return $form;
}

function tribune_history_by_date_handler($form) {
  $date = mktime(0, 0, 0, $form['#post']['by-date-date']['month'], $form['#post']['by-date-date']['day'], $form['#post']['by-date-date']['year']);

  header("Location: ". url("tribune/history/date/". date("Ymd", $date)));
  exit();
}

function tribune_history_by_user_registered_handler($form) {
  header("Location: ". url("tribune/history/user/". $form['#post']['by-user-user']));
  exit();
}

function tribune_history_by_user_anonymous_handler($form) {
  header("Location: ". url("tribune/history/user/anonymous/". $form['#post']['by-user-user']));
  exit();
}

function tribune_history_by_string_handler($form) {
  header("Location: ". url("tribune/history/search/". $form['#post']['by-string-string']));
  exit();
}

/**
  * Returns all the posts for a day, in a formatted string
  * @param $date Show the posts at this date
  * @return String containing the posts in an HTML unordered list
  */
function tribune_history_by_date($date) {

  $date = strtotime($date);

  $contents = "<ul class='tribune-posts tribune-page' id='tribune-pinnipede'>\n";

  $message = check_markup(variable_get('tribune_message', ''));
  if (strlen($message) > 0) {
    $contents .= "<p class='tribune-top-message'>". $message ."</p>\n";
  }

  $r = db_query("SELECT *
                   FROM {tribune}
                  WHERE SUBSTRING(post_time FROM 1 FOR 8) = '%s'
               ORDER BY post_id DESC",
               date("Ymd", $date));

  while ($row = db_fetch_array($r)) {
    $posts[$row['post_id']] = tribune_post_from_row($row);
  }

  $posts = array_reverse($posts);

  $user  = user_load_self(array());
  $login = $user[1]->name;

  if (sizeof($posts) > 0) foreach ($posts as $post) {
    if (!$post['moderated'] || user_access("moderate tribune")) {
      $contents .= print_post($post, FALSE) ."\n";

      $_tribune_current_post_id = -1;
    }
  }

  $contents .= "</ul>\n";

  return $contents;
}

/**
  * Returns all the posts for an user, in a formatted string
  * @param $user Show the posts from this user
  * @return String containing the posts in an HTML unordered list
  */
function tribune_history_by_user($user) {

  $contents = "<ul class='tribune-posts tribune-page' id='tribune-pinnipede'>\n";

  $message = check_markup(variable_get('tribune_message', ''));
  if (strlen($message) > 0) {
    $contents .= "<p class='tribune-top-message'>". $message ."</p>\n";
  }

  $r = db_query("SELECT *
                   FROM {tribune}
                  WHERE login = '%s'
               ORDER BY post_id DESC",
               $user);

  while ($row = db_fetch_array($r)) {
    $posts[$row['post_id']] = tribune_post_from_row($row);
  }

  $posts = array_reverse($posts);

  $user  = user_load_self(array());
  $login = $user[1]->name;

  if (sizeof($posts) > 0) foreach ($posts as $post) {
    if (!$post['moderated'] || user_access("moderate tribune")) {
      $contents .= print_post($post, FALSE) ."\n";

      $_tribune_current_post_id = -1;
    }
  }

  $contents .= "</ul>\n";

  return $contents;
}

function tribune_history_by_user_anonymous($user) {

  $user = '%'. str_replace('*', '%', $user) .'%';

  $contents = "<ul class='tribune-posts tribune-page' id='tribune-pinnipede'>\n";

  $message = check_markup(variable_get('tribune_message', ''));
  if (strlen($message) > 0) {
    $contents .= "<p class='tribune-top-message'>". $message ."</p>\n";
  }

  $r = db_query("SELECT *
                   FROM {tribune}
                  WHERE info LIKE '%s'
                    AND login = ''
               ORDER BY post_id DESC",
               $user);

  while ($row = db_fetch_array($r)) {
    $posts[$row['post_id']] = tribune_post_from_row($row);
  }

  $posts = array_reverse($posts);

  $user  = user_load_self(array());
  $login = $user[1]->name;

  if (sizeof($posts) > 0) foreach ($posts as $post) {
    if (!$post['moderated'] || user_access("moderate tribune")) {
      $contents .= print_post($post, FALSE) ."\n";

      $_tribune_current_post_id = -1;
    }
  }

  $contents .= "</ul>\n";

  return $contents;
}

function tribune_history_by_string($string) {

  $string = '%'. str_replace('*', '%', $string) .'%';

  $contents = "<ul class='tribune-posts tribune-page' id='tribune-pinnipede'>\n";

  $message = check_markup(variable_get('tribune_message', ''));
  if (strlen($message) > 0) {
    $contents .= "<p class='tribune-top-message'>". $message ."</p>\n";
  }

  $r = db_query("SELECT *
                   FROM {tribune}
                  WHERE message LIKE '%s'
               ORDER BY post_id DESC",
               $string);

  while ($row = db_fetch_array($r)) {
    $posts[$row['post_id']] = tribune_post_from_row($row);
  }

  $posts = array_reverse($posts);

  $user  = user_load_self(array());
  $login = $user[1]->name;

  if (sizeof($posts) > 0) foreach ($posts as $post) {
    if (!$post['moderated'] || user_access("moderate tribune")) {
      $contents .= print_post($post, FALSE) ."\n";

      $_tribune_current_post_id = -1;
    }
  }

  $contents .= "</ul>\n";

  return $contents;
}

